[−][src]Type Definition iri_string::types::IriFragmentStr
type IriFragmentStr = RiFragmentStr<IriSpec>;
A borrowed string type for a fragment part of an IRI.
type IriFragmentStr = RiFragmentStr<IriSpec>;
A borrowed string type for a fragment part of an IRI.