Struct Built
struct Built<'a, T: ?Sized> { ... }
Display-able IRI build result.
The value of this type can generate an IRI using From/Into traits or
Display trait.
Security consideration
This can be stringified or directly printed by std::fmt::Display, but note
that this Display does not hide the password part. Be careful not to
print the value using Display for Built<_> in public context.
Implementations
impl<S: Spec> Built<'_, RiAbsoluteStr<S>>
fn ensure_rfc3986_normalizable(self: &Self) -> Result<(), Error>Returns Ok
(())if the IRI is normalizable by the RFC 3986 algorithm.
impl<S: Spec> Built<'_, RiReferenceStr<S>>
fn ensure_rfc3986_normalizable(self: &Self) -> Result<(), Error>Returns Ok
(())if the IRI is normalizable by the RFC 3986 algorithm.
impl<S: Spec> Built<'_, RiRelativeStr<S>>
fn ensure_rfc3986_normalizable(self: &Self) -> Result<(), Error>Returns Ok
(())if the IRI is normalizable by the RFC 3986 algorithm.
impl<S: Spec> Built<'_, RiStr<S>>
fn ensure_rfc3986_normalizable(self: &Self) -> Result<(), Error>Returns Ok
(())if the IRI is normalizable by the RFC 3986 algorithm.
impl<'a, T> Freeze for Built<'a, T>
impl<'a, T> RefUnwindSafe for Built<'a, T>
impl<'a, T> Send for Built<'a, T>
impl<'a, T> Sync for Built<'a, T>
impl<'a, T> Unpin for Built<'a, T>
impl<'a, T> UnsafeUnpin for Built<'a, T>
impl<'a, T> UnwindSafe for Built<'a, T>
impl<'a, T: $crate::fmt::Debug + ?Sized> Debug for Built<'a, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<S: Spec> Display for Built<'_, RiAbsoluteStr<S>>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<S: Spec> Display for Built<'_, RiReferenceStr<S>>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<S: Spec> Display for Built<'_, RiRelativeStr<S>>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<S: Spec> Display for Built<'_, RiStr<S>>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<S: Spec> ToDedicatedString for Built<'_, RiAbsoluteStr<S>>
fn try_to_dedicated_string(self: &Self) -> Result<<Self as >::Target, TryReserveError>
impl<S: Spec> ToDedicatedString for Built<'_, RiReferenceStr<S>>
fn try_to_dedicated_string(self: &Self) -> Result<<Self as >::Target, TryReserveError>
impl<S: Spec> ToDedicatedString for Built<'_, RiRelativeStr<S>>
fn try_to_dedicated_string(self: &Self) -> Result<<Self as >::Target, TryReserveError>
impl<S: Spec> ToDedicatedString for Built<'_, RiStr<S>>
fn try_to_dedicated_string(self: &Self) -> Result<<Self as >::Target, TryReserveError>
impl<T> Any for Built<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Built<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Built<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for Built<'a, T>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for Built<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for Built<'a, T>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T> ToString for Built<'a, T>
fn to_string(self: &Self) -> String
impl<T> ToStringFallible for Built<'a, T>
fn try_to_string(self: &Self) -> Result<String, TryReserveError>[
ToString::to_string]alloc::string::ToString::to_string, but without panic on OOM.
impl<T, U> Into for Built<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Built<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Built<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>
impl<T: ?Sized> Clone for Built<'_, T>
fn clone(self: &Self) -> Self