Enum VisitPurpose
enum VisitPurpose
A purpose of a visit.
This enum is nonexhaustive since this partially exposes the internal implementation of the template expansion, and thus this is subject to change.
Variants
-
Typecheck A visit for type checking.
-
Expand A visit for template expansion to retrieve the value.
Implementations
impl Clone for VisitPurpose
fn clone(self: &Self) -> VisitPurpose
impl Copy for VisitPurpose
impl Debug for VisitPurpose
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl Eq for VisitPurpose
impl Freeze for VisitPurpose
impl PartialEq for VisitPurpose
fn eq(self: &Self, other: &VisitPurpose) -> bool
impl RefUnwindSafe for VisitPurpose
impl Send for VisitPurpose
impl StructuralPartialEq for VisitPurpose
impl Sync for VisitPurpose
impl Unpin for VisitPurpose
impl UnsafeUnpin for VisitPurpose
impl UnwindSafe for VisitPurpose
impl<T> Any for VisitPurpose
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for VisitPurpose
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for VisitPurpose
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for VisitPurpose
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for VisitPurpose
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for VisitPurpose
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for VisitPurpose
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for VisitPurpose
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for VisitPurpose
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>