Function absolute_iri
fn absolute_iri<S: Spec>(s: &str) -> Result<(), Error>
Validates absolute IRI.
This validator corresponds to RiAbsoluteStr and RiAbsoluteString types.
Examples
This type can have an absolute IRI without fragment part.
use ;
assert!;
assert!;
// Scheme `foo` and empty path.
assert!;
// `foo://.../` below are all allowed. See the crate documentation for detail.
assert!;
assert!;
assert!;
assert!;
assert!;
Relative IRI is not allowed.
use ;
// This is relative path.
assert!;
// `/foo/bar` is an absolute path, but it is authority-relative.
assert!;
// `//foo/bar` is termed "network-path reference",
// or usually called "protocol-relative reference".
assert!;
// Empty string is not a valid absolute IRI.
assert!;
Fragment part (such as trailing #foo) is not allowed.
use ;
// Fragment part is not allowed.
assert!;
Some characters and sequences cannot used in an absolute IRI.
use ;
// `<` and `>` cannot directly appear in an absolute IRI.
assert!;
// Broken percent encoding cannot appear in an absolute IRI.
assert!;
assert!;